@@ -22,7 +22,9 @@ from . import s_log , s_db
 #####################################################################
 
 def cleanup( ) :
-    #s_db.filepath_delete_all( )
+    # FIXME TODO only delete the threads db! otherwise another process could be still running! not all
+    # FIXME TOOD count how db files are in dir and report back!
+    s_db.filepath_delete( )
     #s_log.write( "cleanup" )
     pass
 
