@@ -45,7 +45,7 @@ def fsize( ) :
 
 def fsize_limited( ) :
     fs = fsize( )
-    if( fs > 20971520 ) :
+    if( fs > 67108864 ) :
         s_log.write( "ERROR fsize_limited " + str( fs ) )
         return( True )
     return( False )
@@ -57,8 +57,8 @@ def db_stash( ) :
     os.rename( curr_fp , new_fp )
     
     data = {
-        "curr_fp":curr_fp,
-        "new_fp":new_fp
+        "curr_fp" : curr_fp ,
+        "new_fp" : new_fp
     }
 
     return( s_util.json_encode( data ) )
@@ -599,7 +599,16 @@ def files_create( fp , trimpath = "" ) :
     with open( fp , mode = "rb" ) as file : 
         fc = file.read( )
 
+    ####################################################################
 
+    # FIXME TODO WARNING only for HTML files and given macro name
+    if( s_util.path_ext( fp ) == ".html" ) :
+        fc = fc.decode( "utf8" ).replace( "_SAPI_DB_FILES_MACRO_HTML_CACHEBUST_" , s_util.time_hexepoch_str( ) ).encode( "utf8" )
+
+    #print( fp )
+
+    ####################################################################
+    
     # FIXME TODO use better hash lib blake2b?
     fh = hashlib.md5( fc ).hexdigest( )
 
@@ -810,7 +819,7 @@ def files_createall( pat , trim_path = True ) :
     # FIXME TODO WARNING this removes "chars"!
     pat_trim = pat.rstrip( "**" )
     if( pat_trim == pat ) :
-        if(trim_path):
+        if( trim_path ) :
             pat_trim = ""
 
     files = s_util.glob_files( pat , True )
