@@ -36,6 +36,7 @@ import threading
 from datetime import datetime , timedelta , timezone
 
 import datetime as _dt
+import dateutil.parser
 
 from subprocess import Popen, PIPE
 
@@ -525,7 +526,7 @@ def environ_isdockerrunning( ) :
 
 
 def environ_getall( ) :
-    return( os.environ )
+    return( dict( os.environ ) )
 
 def environ_get( k ) :
     if k in os.environ :
@@ -564,6 +565,10 @@ def display_time( seconds , granularity = 2 ) :
     return ', '.join( result[ :granularity ] )
 
 
+def datetimestr_to_unixtime(dt_str):
+    return(dateutil.parser.parse(dt_str).timestamp())
+
+
 def datetime_strtotimestampms( dtstr ) :
     return( datetime.strptime( dtstr , "%Y-%m-%dT%H:%M:%S" ).replace(tzinfo=timezone.utc).timestamp()*1000 )
 
@@ -596,6 +601,9 @@ def time_nowms( ) :
 def time_now_str( ) :
     return( str( round( time_now( ) ) ) )
 
+def time_hexepoch_str( ) :
+    return( hex( round( time_now( ) - 1664792185 ) )[ 2: ] )
+
 def datetime_utcnow( ) :
     return( datetime.utcnow( ) )
 
@@ -618,6 +626,8 @@ def idle( ) :
         s_log.write( "IDLE" )
         time.sleep( 86400 )
 
+def datetime_add_timedelta( dt , sec ) :
+    return( dt + timedelta( seconds = sec ) )
 
 def datetime_nowutcstr( td = 0 ) :
 
@@ -688,6 +698,12 @@ def datetime_initstartend( p , es , ee , ew ) :
 
 ################
 
+
+def path_ext( fp ) :
+
+    file_extension = Path( fp ).suffix
+    return( file_extension)
+
 def path_mkdirs( dp ) :
 
     path = Path( dp )
@@ -763,6 +779,12 @@ def sys_path_append_fp( fp ) :
 def file_stat( fp ) :
     return( os.stat( fp ) )
 
+
+def file_stat_dict(fp: str) -> dict:
+    s_obj = os.stat(fp)
+    return {k: getattr(s_obj, k) for k in dir(s_obj) if k.startswith('st_')}
+
+
 def file_size( fp ) :
     return( os.path.getsize( fp ) )
 
